@@ -19,8 +19,6 @@
 #include "author.h"
 #include "knewstuffcore_export.h"
 
-#include <memory>
-
 class testEntry;
 class QDomElement;
 class QXmlStreamReader;
@@ -51,6 +49,22 @@ class KNEWSTUFFCORE_EXPORT Entry
     Q_GADGET
 public:
     typedef QList<Entry> List;
+    Q_PROPERTY(QString providerId READ providerId)
+    Q_PROPERTY(QString uniqueId READ uniqueId)
+    Q_PROPERTY(KNSCore::Entry::Status status READ status)
+    Q_PROPERTY(KNSCore::Entry::EntryType entryType READ entryType)
+
+    Q_PROPERTY(QString name READ name)
+    Q_PROPERTY(KNSCore::Author author READ author)
+    Q_PROPERTY(QString shortSummary READ shortSummary)
+    Q_PROPERTY(QString summary READ summary)
+    // TODO  Q_PROPERTY(QString previews READ previews)
+    Q_PROPERTY(QUrl homepage READ homepage)
+    Q_PROPERTY(QString donationLink READ donationLink)
+    Q_PROPERTY(int numberOfComments READ numberOfComments)
+    Q_PROPERTY(int rating READ rating)
+    Q_PROPERTY(int downloadCount READ downloadCount)
+    Q_PROPERTY(QList<KNSCore::Entry::DownloadLinkInformation> downloadLinks READ downloadLinkInformationList)
 
     /**
      * Status of the entry. An entry will be downloadable from the provider's
@@ -120,6 +134,7 @@ public:
         CatalogEntry = 0, ///< These are the main entries that KNewStuff can get the details about and download links for.
         GroupEntry ///< these are entries whose payload is another feed. Currently only used by the OPDS provider.
     };
+    Q_ENUM(EntryType)
 
     /**
      * Constructor.
@@ -539,6 +554,8 @@ private:
     friend class Cache;
     friend class Installation;
     friend class AtticaProvider;
+    friend class AtticaRequester;
+    friend class Transaction;
     friend testEntry;
     KNEWSTUFFCORE_NO_EXPORT void setEntryRequestedId(const QString &id);
     QDomElement entryXML() const;
